#
# spec file for package python-mysql-connector-python
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-mysql-connector-python
Version:        9.1.0
Release:        bp156.4.3.1
Summary:        MySQL driver written in Python
License:        SUSE-GPL-2.0-with-FLOSS-exception
Group:          Development/Languages/Python
URL:            http://dev.mysql.com/doc/connector-python/en/index.html
# GitHub: https://github.com/mysql/mysql-connector-python
Source:         https://dev.mysql.com/get/Downloads/Connector-Python/mysql-connector-python-%{version}-src.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module protobuf}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  mariadb
BuildRequires:  python-rpm-macros
Requires:       python-dnspython
Requires:       python-protobuf
%python_subpackages

%description
MySQL driver written in Python which does not depend on MySQL C client libraries and implements the DB API v2.0 specification (PEP-249).

%prep
%autosetup -p1 -n mysql-connector-python-%{version}-src

%build
pushd mysql-connector-python
%python_build
popd
pushd mysqlx-connector-python
%python_build
popd

%install
pushd mysql-connector-python
%python_install
popd
pushd mysqlx-connector-python
%python_install
popd
%python_expand %fdupes %{buildroot}%{$python_sitearch}

#FIXME(toabctl): Reenable testuite
# probably won't work against mariadb 10
# the test script is using rather deep details
# of `mysql` table structure
# --matejcik
#check
#python unittests.py --with-mysql=/usr

%files %{python_files}
%license LICENSE.txt
%doc README.txt CHANGES.txt
%{python_sitearch}/mysql
%{python_sitearch}/mysql*.egg-info
%{python_sitearch}/mysqlx

%changelog
* Mon Oct 21 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 9.1.0 (bsc#1231740, CVE-2024-21272)
  - WL#16452: Bundle all installable authentication plugins when building the C-extension
  - WL#16444: Drop build support for DEB packages
  - WL#16442: Upgrade gssapi version to 1.8.3
  - WL#16411: Improve wheel metadata information for Classic and XDevAPI connectors
  - WL#16341: OpenID Connect (Oauth2 - JWT) Authentication Support
  - WL#16307: Remove Python 3.8 support
  - WL#16306: Add support for Python 3.13
  - BUG#37055435: Connection fails during the TLS negotiation when specifying TLSv1.3 ciphers
  - BUG#37013057: mysql-connector-python Parameterized query SQL injection
  - BUG#36765200: python mysql connector 8.3.0 raise %%-.100s:%%u when input a wrong host
  - BUG#36577957: Update charset/collation description indicate this is 16 bits
- 9.0.0:
  - WL#16350: Update dnspython version
  - WL#16318: Deprecate Cursors Prepared Raw and Named Tuple
  - WL#16284: Update the Python Protobuf version
  - WL#16283: Remove OpenTelemetry Bundled Installation
  - BUG#36664998: Packets out of order error is raised while changing user in aio
  - BUG#36611371: Update dnspython required versions to allow latest 2.6.1
  - BUG#36570707: Collation set on connect using C-Extension is ignored
  - BUG#36476195: Incorrect escaping in pure Python mode if sql_mode includes NO_BACKSLASH_ESCAPES
  - BUG#36289767: MySQLCursorBufferedRaw does not skip conversion
- 8.4.0
  - WL#16203: GPL License Exception Update
  - WL#16173: Update allowed cipher and cipher-suite lists
  - WL#16164: Implement support for new vector data type
  - WL#16127: Remove the FIDO authentication mechanism
  - WL#16053: Support GSSAPI/Kerberos authentication on Windows using authentication_ldap_sasl_client plug-in for C-extension
  - BUG#36227964: Improve OpenTelemetry span coverage
  - BUG#36167880: Massive memory leak mysqlx native Protobuf adding to collection
- 8.3.0
  - WL#16015: Remove use of removed COM_ commands
  - WL#15985: Support GSSAPI/Kerberos authentication on Windows using authentication_ldap_sasl_client plug-in for Pure Python
  - WL#15983: Stop using mysql_ssl_set api
  - WL#15982: Remove use of mysql_shutdown
  - WL#15950: Support query parameters for prepared statements
  - WL#15942: Improve type hints and standardize byte type handling
  - WL#15836: Split mysql and mysqlx into different packages
  - WL#15523: Support Python DB API asynchronous execution
  - BUG#35912790: Binary strings are converted when using prepared statements
  - BUG#35832148: Fix Django timezone.utc deprecation warning
  - BUG#35710145: Bad MySQLCursor.statement and result when query text contains code comments
  - BUG#21390859: STATEMENTS GET OUT OF SYNCH WITH RESULT SETS
* Wed Nov  1 2023 Enno Gotthold <egotthold@suse.com>
- Update to version 8.2.0
- Remove:
  * remove-require-version-constraint.patch
* Thu Jun 11 2020 Rolf Krahl <rolf@rotkraut.de>
- Add requirement on python-dnspython and python-protobuf (bsc#1172784)
- Add remove-require-version-constraint.patch
* Wed Mar 18 2020 Dirk Mueller <dmueller@suse.com>
- update to 8.0.19 (bsc#1122204 - CVE-2019-2435):
  - WL#13531: Remove xplugin namespace
  - WL#13372: DNS SRV support
  - WL#12738: Specify TLS ciphers to be used by a client or session
  - BUG#30270760: Fix reserved filed should have a length of 22
  - BUG#29417117: Close file in handle load data infile
  - WL#13330: Single C/Python (Win) MSI installer
  - WL#13335: Connectors should handle expired password sandbox without SET operations
  - WL#13194: Add support for Python 3.8
  - BUG#29909157: Table scans of floats causes memory leak with the C extension
  - BUG#25349794: Add read_default_file alias for option_files in connect()
  - WL#13155: Support new utf8mb4 bin collation
  - WL#12737: Add overlaps and not_overlaps as operator
  - WL#12735: Add README.rst and CONTRIBUTING.rst files
  - WL#12227: Indexing array fields
  - WL#12085: Support cursor prepared statements with C extension
  - BUG#29855733: Fix error during connection using charset and collation combination
  - BUG#29833590: Calling execute() should fetch active results
  - BUG#21072758: Support for connection attributes classic
  - WL#12864: Upgrade of Protobuf version to 3.6.1
  - WL#12863: Drop support for Django versions older than 1.11
  - WL#12489: Support new session reset functionality
  - WL#12488: Support for session-connect-attributes
  - WL#12297: Expose metadata about the source and binaries
  - WL#12225: Prepared statement support
  - BUG#29324966: Add missing username connection argument for driver compatibility
  - BUG#29278489: Fix wrong user and group for Solaris packages
  - BUG#29001628: Fix access by column label in Table.select()
  - BUG#28479054: Fix Python interpreter crash due to memory corruption
  - BUG#27897881: Empty LONG BLOB throws an IndexError
  - BUG#29260128: Disable load data local infile by default
  - WL#12607: Handling of Default Schema
  - WL#12493: Standardize count method
  - WL#12492: Be prepared for initial notice on connection
  - BUG#28646344: Remove expression parsing on values
  - BUG#28280321: Fix segmentation fault when using unicode characters in tables
  - BUG#27794178: Using use_pure=False should raise an error if cext is not available
  - BUG#27434751: Add a TLS/SSL option to verify server name
  - WL#12239: Add support for Python 3.7
  - WL#12226: Implement connect timeout
  - WL#11897: Implement connection pooling for xprotocol
  - BUG#28278352: C extension mysqlx Collection.add() leaks memory in sequential calls
  - BUG#28037275: Missing bind parameters causes segfault or unclear error message
  - BUG#27528819: Support special characters in the user and password using URI
  - WL#11951: Consolidate discrepancies between pure and c extension
  - WL#11932: Remove Fabric support
  - WL#11898: Core API v1 alignment
  - BUG#28188883: Use utf8mb4 as the default character set
  - BUG#28133321: Fix incorrect columns names representing aggregate functions
  - BUG#27962293: Fix Django 2.0 and MySQL 8.0 compatibility issues
  - BUG#27567999: Fix wrong docstring in ModifyStatement.patch()
  - BUG#27277937: Fix confusing error message when using an unsupported collation
  - BUG#26834200: Deprecate Row.get_string() method
  - BUG#26660624: Fix missing install option in documentation
  - WL#11668: Add SHA256_MEMORY authentication mechanism
  - WL#11614: Enable C extension by default
  - WL#11448: New document _id generation support
  - WL#11282: Support new locking modes NOWAIT and SKIP LOCKED
  - BUG#27639119: Use a list of dictionaries to store warnings
  - BUG#27634885: Update error codes for MySQL 8.0.11
  - BUG#27589450: Remove upsert functionality from WriteStatement class
  - BUG#27528842: Fix internal queries open for SQL injection
  - BUG#27364914: Cursor prepared statements do not convert strings
  - BUG#24953913: Fix failing unittests
  - BUG#24948205: Results from JSON_TYPE() are returned as bytearray
  - BUG#24948186: JSON type results are bytearray instead of corresponding python type
  - WL#11372: Remove configuration API
  - WL#11303: Remove CreateTable and CreateView
  - WL#11281: Transaction savepoints
  - WL#11278: Collection.create_index
  - WL#11149: Create Pylint test for mysqlx
  - WL#11142: Modify/MergePatch
  - WL#11079: Add support for Python 3.6
  - WL#11073: Add caching_sha2_password authentication plugin
  - WL#10975: Add Single document operations
  - WL#10974: Add Row locking methods to find and select operations
  - WL#10973: Allow JSON types as operands for IN operator
  - WL#10899: Add support for pure Python implementation of Protobuf
  - WL#10771: Add SHA256 authentication
  - WL#10053: Configuration handling interface
  - WL#10772: Cleanup Drop APIs
  - WL#10770: Ensure all Session connections are secure by default
  - WL#10754: Forbid modify() and remove() with no condition
  - WL#10659: Support utf8mb4 as default charset
  - WL#10658: Remove concept of NodeSession
  - WL#10657: Move version number to 8.0
  - WL#10198: Add Protobuf C++ extension implementation
  - WL#10004: Document UUID generation
  - BUG#26175003: Fix Session.sql() when using unicode SQL statements with Python 2.7
  - BUG#26161838: Dropping an non-existing index should succeed silently
  - BUG#26160876: Fix issue when using empty condition in Collection.remove() and Table.delete()
  - BUG#26029811: Improve error thrown when using an invalid parameter in bind()
  - BUG#25991574: Fix Collection.remove() and Table.delete() missing filters
  - WL#10452: Add Protobuf C++ extension for Linux variants and Mac OSX
  - WL#10081: DevAPI: IPv6 support
  - BUG#25614860: Fix defined_as method in the view creation
  - BUG#25519251: SelectStatement does not implement order_by() method
  - BUG#25436568: Update available operators for XPlugin
  - BUG#24954006: Add missing items in CHANGES.txt
  - BUG#24578507: Fix import error using Python 2.6
  - BUG#23636962: Fix improper error message when creating a Session
  - BUG#23568207: Fix default aliases for projection fields
  - BUG#23567724: Fix operator names
  - DevAPI: Schema.create_table
  - DevAPI: Flexible Parameter Lists
  - DevAPI: New transports: Unix domain socket
  - DevAPI: Core TLS/SSL options for the mysqlx URI scheme
  - DevAPI: View DDL with support for partitioning in a cluster / sharding
  - BUG#24520850: Fix unexpected behavior when using an empty collection name
  - Add support for Protocol Buffers 3
  - Add View support (without DDL)
  - Implement get_default_schema() method in BaseSchema
  - DevAPI: Per ReplicaSet SQL execution
  - DevAPI: XSession accepts a list of routers
  - DevAPI: Define action on adding empty list of documents
  - BUG#23729357: Fix fetching BIT datatype
  - BUG#23583381: Add who_am_i and am_i_real methods to DatabaseObject
  - BUG#23568257: Add fetch_one method to mysqlx.result
  - BUG#23550743: Add close method to XSession and NodeSession
  - BUG#23550057: Add support for URI as connection data
  - Provide initial implementation of new DevAPI
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Feb 15 2018 jacobwinski@gmail.com
- Update to 2.1.7:
  * BUG#26376334: Fix prepared statements in MySQL 8.0
  * BUG#25965922: Add support for Django 1.11
  * BUG#24659561: Fix MySQLCursor.executemany() when using utf8mb4 charset
  * BUG#24342757: Fix unclosed socket on connection failure
  * BUG#22880163: Fix memory leak on using Named Tuple Cursors
  * BUG#22825962: Fix memory leak on escape_string()
  * BUG#22564149: Fix cmd_query_iter() when using bytestrings with Python 2
  * BUG#21947091: Add ssl_disabled option
- Update to 2.1.6:
  * BUG#25726671: Fix compatibility issues with the latest Django versions
  * BUG#25558885: Set default connection timeout to pure connector/python
  * BUG#25397650: Verify server certificate only if ssl_verify_cert is True
  * BUG#25589496: Don't convert to unicode if non-ascii data is present
  * BUG#25383644: Add connection back to pool on exception
  * BUG#22476689: Importing world.sql fails with cext enabled
  * BUG#20736339: Expect multiple include directories from mysql_config
  * BUG#19685386: C extension tests are failing using MySQL 5.7.4
- Update to 2.1.5:
  * BUG#25111218: Fix duplicate logic for reading EOF packet
  * BUG#21656282: Connection fails using unicode passwords with C extension
  * BUG#21530841: Select statement fails for results with more than 4096 columns
  * BUG#21530100: Fix reading option files
  * BUG#21477493: Fix RE_SQL_INSERT_STMT to correctly match Insert Statement
  * BUG#21476495: Fix set_charset_collation() for an invalid charset provided
* Thu Feb 15 2018 jacobwinski@gmail.com
- Fix spec file bug not installing c libs
* Mon Feb 12 2018 jacobwinski@gmail.com
-  Update spec file with needed BuildRequires.
* Mon Feb 12 2018 jacobwinski@gmail.com
- Convert to singlespec
* Fri Oct 21 2016 jmatejek@suse.com
- update to 2.1.4
  * significant incompatible changes from 1.2 line
  * better Django compatibility
  * C extension linking to libmysqlclient is available
    (not included in this version of package)
  * bug fixes
- includes fix for CVE-2016-5598, bsc#1005559
* Tue Oct 21 2014 dmueller@suse.com
- fix license to SUSE-GPL-2.0-with-FLOSS-exception
* Tue Sep 23 2014 tbechtold@suse.com
- Initial version
